==> haskell-system-filepath-0.4.14.1-91.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-system-filepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-filepath
version:              0.4.14.1
visibility:           public
id:                   system-filepath-0.4.14.1-DPifgQZi1apEQ51HShU6I3
key:                  system-filepath-0.4.14.1-DPifgQZi1apEQ51HShU6I3
license:              MIT
copyright:            John Millikin 2010-2012
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    High-level, byte-based file and directory path manipulations (deprecated)

description:
    High-level, byte-based file and directory path manipulations (deprecated).

category:             System
abi:                  596284a00044617183f481c2cd2d57f5
exposed:              True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules

hidden-modules:       Filesystem.Path.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-filepath
hs-libraries:         HSsystem-filepath-0.4.14.1-DPifgQZi1apEQ51HShU6I3
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock

haddock-html:         /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-filepath-0.4.14.1-92-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-system-filepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-filepath
version:              0.4.14.1
visibility:           public
id:                   system-filepath-0.4.14.1-HuIxoRxmfFQmMHeAd2Im
key:                  system-filepath-0.4.14.1-HuIxoRxmfFQmMHeAd2Im
license:              MIT
copyright:            John Millikin 2010-2012
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    High-level, byte-based file and directory path manipulations (deprecated)

description:
    High-level, byte-based file and directory path manipulations (deprecated).

category:             System
abi:                  6e290a79f9293d7ec1bcccb3a4acf2b5
exposed:              True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules

hidden-modules:       Filesystem.Path.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/system-filepath-0.4.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-filepath
hs-libraries:         HSsystem-filepath-0.4.14.1-HuIxoRxmfFQmMHeAd2Im
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock

haddock-html:         /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
